

%macro ddcf_delete_consensus_plan_stp;

	%let job_rc=0;
	%let job_rc_msg=;

	/* Assign FM libraries */
	%ddcf_assign_fm_libraries;

	/*Assign transaction server library*/
	%ddcf_assign_trans_library(libref=uiart);

	/* Define connection string for transactional server*/
	%ddcf_connect_to_trans_db;


	/* Update Status Code: Consensus complete inprogress */

	proc sql noprint;
		update uiart.consensus_plan_details 
		set consensus_status_no = 27 
		where consensus_plan_id = &consensus_plan_id.;
	quit;
	%rcset(&sqlrc);
	%if (&job_rc>4) %then %do;
		%put ERROR: While deleting FM consensus plan data.;
		%goto exit;
	%end;

	/* Check schema id exists or not. */

	%let reccnt=0;

	proc sql noprint;
		select count(*) into :reccnt 
		from scratch.schema 
		where plan_id=&consensus_plan_id.;
	quit;
	%rcset(&sqlrc);
	%if (&job_rc>4) %then %do;
		%put ERROR: While deleting FM consensus plan data.;
		%goto exit;
	%end;

	%if &reccnt. gt 0 %then %do;

		/* Get schema id */

		%let schema_id=;
		%ddcf_get_schema_id(plan_id=&consensus_plan_id.);

		%if (&job_rc>4) %then %do;
			%put ERROR: While deriving schema id.;
			%goto exit;
		%end;
		
		/* Delete FM side data */

		%ddcf_delete_fm_consensus_data;

		%if (&job_rc>4) %then %do;
			%put ERROR: While deleting FM consensus plan data.;
			%goto exit;
		%end;

	%end;
	%else %do;
		
		%let reccnt1=0;

		proc sql noprint;
			select count(*) into :reccnt1 
			from uiart.consensus_plan_details
			where consensus_plan_id = &consensus_plan_id.;
		quit;
		%rcset(&sqlrc);
		%if (&job_rc>4) %then %do;
			%put ERROR: While deleting FM consensus plan data.;
			%goto exit;
		%end;
		
		%if &reccnt1. gt 0 %then %do;

			/* Get schema id */

			%let schema_id=;

			proc sql noprint;
				select consensus_plan_nm into :schema_id
				from uiart.consensus_plan_details
				where consensus_plan_id = &consensus_plan_id.;
			quit;
			%rcset(&sqlrc);
			%if (&job_rc>4) %then %do;
				%put ERROR: While deleting FM consensus plan data.;
				%goto exit;
			%end;
		%end;
		%else %do;
			%put NOTE: Consensus plan does not exists.;
			%let job_rc=5;
			%goto exit;
		%end;
	%end;

	%if ( &reccnt1. gt 0 ) or ( &reccnt. gt 0 ) %then %do;

		%let schema_id=%sysfunc(ktrim(%sysfunc(kleft(&schema_id.))));
		
		/* Delete Plan Exploration tables */

		%ddcf_delete_planexpl_tables;

		%if (&job_rc>4) %then %do;
			%put ERROR: While deleting consensus plan exploration data.;
			%goto exit;
		%end;
		
		/* Delete consensus uiart and scratch data */

		%ddcf_delete_consensus_data;

		%if (&job_rc>4) %then %do;
			%put ERROR: While deleting UIART and other consensus data.;
		%end;

	%end;

%exit:
	%if (&job_rc>4) %then %do;

		proc sql noprint;
			update uiart.consensus_plan_details 
			set consensus_status_no = 28
			where consensus_plan_id = &consensus_plan_id.;
		quit;
		%rcset(&sqlrc);

	%end;

/* De-assign FM libraries */  
	%ddcf_deassign_fm_libraries;
	libname uiart clear;
%mend;

%ddcf_capture_log(logprefix=delete_consensus,log_id=&consensus_plan_id.);

%ddcf_delete_consensus_plan_stp;

%ddcf_reset_log;
